@@ -1,5 +1,5 @@
 """Top-level package for EpiBOX."""
 
 __author__ = """Ana Sofia Carmo"""
-__email__ = 'anascacais@gmail.com'
-__version__ = '1.0.0'
+__email__ = "anascacais@gmail.com"
+__version__ = "1.1.5"
