@@ -9,9 +9,13 @@ import numpy as np
 # local
 from epibox.common.connect_device import connect_device
 from epibox.exceptions.exception_manager import error_kill
+from epibox import config_debug
 
 def start_devices(client, devices, fs, mac_channels, header):
 
+    # Start acquisition with the biosignal acquisition devices, considering the chosen sampling ferquency
+    # and channels
+
     dig_Out = 0
     now = datetime.now()
     sync_param = {'flag_sync' : 0 , 'inittime' : time.time(), 'strtime': time.time(), 'sync_time' : now.strftime("%Y-%m-%d %H:%M:%S.%f").rstrip('0'), 'dig_Out' : dig_Out, 'close_file' : 0, 'mode': 0, 'diff': 1000, 'save_log': 1, 'count_a': 1000, 'sync_append': 0}
@@ -31,7 +35,8 @@ def start_devices(client, devices, fs, mac_channels, header):
         device.start(SamplingRate=fs, analogChannels=channels)
 
     now = datetime.now()
-    print('start {}'.format(now))
+    
+    config_debug.log('start {now}')
     sync_param['sync_time'] = now.strftime("%Y-%m-%d %H:%M:%S.%f")
 
     client.publish('rpi', str(['ACQUISITION ON']))                 
@@ -41,10 +46,16 @@ def start_devices(client, devices, fs, mac_channels, header):
 
 def connect_devices(client, devices, opt, already_timed_out, a_file=None, files_open=True):
 
+    
+    # This script attempts to connect to the default biosignal acquisition devices in a continuous loop. 
+    # The loop stops only if:
+    #       - connection is successful 
+    #       - timeout is achieved (2min)
+
     for mac in opt['devices_mac']:
 
         init_connect_time = time.time()
-        print('Searching for Module...' + mac)
+        config_debug.log(f'Searching for Module... {mac}')
 
         i = 0
         while client.keepAlive:
@@ -57,7 +68,6 @@ def connect_devices(client, devices, opt, already_timed_out, a_file=None, files_
             try:
                 
                 connected = False
-                time.sleep(3)
                 connected, devices = connect_device(mac, client, devices)
 
                 if connected and mac in [d.macAddress for d in devices]:
@@ -87,13 +97,15 @@ def connect_devices(client, devices, opt, already_timed_out, a_file=None, files_
 
 
 def pause_devices(client, devices):
+    
+    
 
     for device in devices:
 
         try:
             device.stop()
         except Exception as e:
-            print(e)
+            config_debug.log(e)
             continue
 
     client.publish('rpi', str(['PAUSED']))
