@@ -4,6 +4,8 @@ from copy import copy
 # third-party
 import numpy as np
 
+from epibox import config_debug
+
 
 
 def read_modules(devices, mac_channels, sensors, header):
@@ -11,7 +13,8 @@ def read_modules(devices, mac_channels, sensors, header):
     
     t = np.array([])
     t_display = np.array([])
-    #print('devices: {}'.format([d.macAddress for d in devices]))
+    # 
+    # config_debug.log('devices: {}'.format([d.macAddress for d in devices]))
     channels2get = [int(mac_chn[1])-1 for mac_chn in mac_channels]
         
     for i, device in enumerate(devices):
@@ -40,7 +43,7 @@ def read_modules(devices, mac_channels, sensors, header):
 
             t_read = np.hstack((np.reshape(np.array(seq), (-1,1)), t_nseq))
 
-        #print(t_read)
+        #config_debug.log(t_read)
 
         n = 0
         display_aux = np.array([])
